@@ -11,10 +11,13 @@
 */
 
 #include "AccessRecordInterface.h"
-#include <memory>
 
 
+/*!
+  \brief PC ɐтۑ
+*/
 class AccessRecordPC : public AccessRecordInterface {
+  AccessRecordPC(void);
   AccessRecordPC(const AccessRecordPC& rhs);
   AccessRecordPC& operator = (const AccessRecordPC& rhs);
 
@@ -22,12 +25,18 @@ class AccessRecordPC : public AccessRecordInterface {
   const std::auto_ptr<pImpl> pimpl;
 
  public:
-  AccessRecordPC(void);
+  /*!
+    \brief RXgN^
+
+    \param mode [i] ^CsO[h
+  */
+  AccessRecordPC(const TypingMode mode);
   ~AccessRecordPC(void);
 
-  bool record(const recordLine_t& data);
-  bool load(std::vector<recordLine_t>& data, time_t from, time_t to,
-            size_t max_num);
+  bool save(const TypingRecorder::GameSettings& data);
+  bool load(std::vector<TypingRecorder::GameSettings>& data,
+            const char* user_name,
+            time_t from, time_t to, size_t max_num);
 };
 
 #endif /* !ACCESS_RECORD_PC_H */
