@@ -8,12 +8,15 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo oϐ̖𓝈ꂷ
 */
 
 #include "Component.h"
 #include "TypingTextConverter.h"
 #include <string>
 
+
 namespace beego {
   class GuiManager;
   class Layer;
@@ -25,6 +28,8 @@ namespace beego {
   class SoundEffectManager;
 };
 class TypingRecorder;
+class AccessSettings;
+class VoicePlayer;
 
 
 /*!
@@ -32,6 +37,7 @@ class TypingRecorder;
 */
 class CommonResources {
   CommonResources(void);
+  CommonResources(const char* savedir);
   CommonResources(const CommonResources& rhs);
   CommonResources& operator = (const CommonResources& rhs);
 
@@ -39,34 +45,44 @@ class CommonResources {
   const std::auto_ptr<pImpl> pimpl;
 
  public:
+  //////////////////////////////////////////////////////////////////////
+  // GUI 
   beego::GuiManager* gui;       //!< GUI Ǘ
   beego::Layer* front_layer;    //!< OiC[
   beego::Layer* back_layer;     //!< wiC[
-  boost::shared_ptr<beego::ConsolePanelComponent> debug;
+  boost::shared_ptr<beego::ConsolePanelComponent> debug; //!< fobO\p
 
   beego::Component back_label;  //!< wi摜
   beego::TtfResource* font;     //!< tHg\[X
+  beego::Component menu_icon;   //!< j[ACR
+  beego::Component user_label;  //!< [U
 
   beego::InputHandler* input;   //!< ̓nh
   boost::shared_ptr<beego::InputReceiveComponent> input_receiver; //!< ͎M
 
+  //////////////////////////////////////////////////////////////////////
+  // y
   beego::MusicManager* music;              //!< wiȂ̊Ǘ
   beego::SoundEffectManager* sound_effect; //!< ʉ̊Ǘ
 
-  TypingTextConverter::ConvertType convert_type; //!< ȕϊ
-
   TypingRecorder* recorder;     //!< ^CsŐL^
-  size_t practice_num;          //!< K
+  int practice_num;             //!< K
   std::vector<int> waka_order;  //!< â̕
 
-  std::string user_name;        //!< [U
+  VoicePlayer* voice_;           //!< rݏグ
+
+  //////////////////////////////////////////////////////////////////////
+  // ݒ
+  TypingTextConverter::ConvertType convert_type; //!< ȕϊ
+  std::string savedir_;            //!< f[^̕ۑfBNg
+  AccessSettings* settings;        //!< ݒ
 
   ~CommonResources(void);
 
   /*!
     \brief ʃ\[Xւ̊ǗIuWFNgԂ
   */
-  static CommonResources* getObject(void);
+  static CommonResources* getObject(const char* savedir = NULL);
 
   /*!
     \brief GUI \[X̏
@@ -95,6 +111,27 @@ class CommonResources {
     \brief y̏
   */
   void initializeMusic(void);
+
+  /*!
+    \brief ݂̃[U̎擾
+  */
+  const char* getUserName(void) const;
+
+  /*!
+    \brief [U̍폜
+
+    \brief user_name [i] ǉ[U
+  */
+  void addUser(const char* user_name, const char* password);
+
+  /*!
+    \brief w胆[U̍폜
+
+    \brief user_name [i] 폜[Uԍ
+  */
+  void deleteUser(int  user_index);
+
+  void updateUserLable(void);
 };
 
 #endif /* !COMMON_RESOURCES_H */
