@@ -5,6 +5,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo PC ̃[UƏdȂAʂ
 */
 
 #include "CreateUser.h"
@@ -13,6 +15,7 @@
 #include "SystemDefinition.h"
 #include "DrawsDefinition.h"
 #include "ResourceDefinition.h"
+#include "AccessSettings.h"
 #include "GuiManager.h"
 #include "Layer.h"
 #include "InputEvent.h"
@@ -23,10 +26,11 @@
 #include "LabelComponent.h"
 #include "TextInputComponent.h"
 #include "InputReceiveComponent.h"
-#include "HorizontalSelectComponent.h"
+#include "SelectComponent.h"
 #include "BaseEntity.h"
 #include "StateMachine.h"
 #include "GetAccountName.h"
+#include "RemoveFile.h"
 #include "ThreadCreator.h"
 #include "SdlUtils.h"
 #include "Delay.h"
@@ -85,7 +89,7 @@ struct CreateUser::pImpl {
     TextProperty message_property;
     Surface message_surface;
     Component message_label;
-    boost::shared_ptr<HorizontalSelectComponent> selector;
+    boost::shared_ptr<SelectComponent> selector;
     size_t now_progress;
     Surface server_surface;
     Component server_label;
@@ -98,7 +102,7 @@ struct CreateUser::pImpl {
                          NormalSize, Fore, Back, true),
         message_surface(new TextSurface(message_property)),
         message_label(new LabelComponent(message_surface)),
-        selector(new HorizontalSelectComponent(message_property, White)),
+        selector(new SelectComponent(message_property, White)),
         now_progress(0) {
 
       // ZN^[̏
@@ -107,6 +111,7 @@ struct CreateUser::pImpl {
       selector->addItem("3");
       selector->addItem("4");
       selector->setItemsOffset(NormalSize/2);
+      selector->disableInput();
 
       SDL_Rect position;
       set_SdlRect(&position, TextOffset,
@@ -609,7 +614,7 @@ struct CreateUser::pImpl {
       if (first_slash != std::string::npos) {
         server = server_address.substr(0, first_slash);
         address = server_address.substr(first_slash, std::string::npos)
-          + "/registerUser.php?name=" + std::string(&user_name[0]);
+          + "registerUser.php?name=" + std::string(&user_name[0]);
       } else {
         server = server_address;
         // !!! dȂƂ
@@ -627,7 +632,8 @@ struct CreateUser::pImpl {
         // AhXԈႢ
         return AddressError;
       }
-      std::ofstream image_file("savedata/antispam.jpg");
+      std::string save_path = common->savedir_ + "antispam.jpg";
+      std::ofstream image_file(save_path.c_str());
       image_file.write(&image_data[0], static_cast<int>(image_data.size()));
 
       return 0;
@@ -724,10 +730,12 @@ struct CreateUser::pImpl {
     void enter(Schedule* type) {
 
       // 摜̍XV
-      Surface new_image_surface(new ImageSurface("savedata/antispam.jpg"));
+      std::string save_path = common->savedir_ + "antispam.jpg";
+      Surface new_image_surface(new ImageSurface(save_path.c_str()));
       std::swap(image_surface, new_image_surface);
       Component new_image_label(new LabelComponent(image_surface));
       std::swap(image_label, new_image_label);
+      removeFile(save_path.c_str());
 
       SDL_Rect position;
       set_SdlRect(&position, PasswordX, PasswordY);
@@ -808,6 +816,15 @@ struct CreateUser::pImpl {
           thread.wait(&ret);
           if (SDL_SemValue(thread_args.result_) > 0) {
             // 擾 "O.K." I
+
+            // [U̒ǉ
+            const char* user_name =
+              NameInputState::getObject(common)->getLoginName();
+            if (strlen(user_name) > 0) {
+              const char* password = getPassword();
+              common->addUser(user_name, password);
+              common->settings->save();
+            }
             type->changeState(CompleteState::getObject(common));
 
           } else {
@@ -876,7 +893,8 @@ struct CreateUser::pImpl {
         HttpInputState::getObject(common)->getServerAddress();
 
       // [U̎擾
-      const char* user_name = NameInputState::getObject(common)->getLoginName();
+      const char* user_name =
+        NameInputState::getObject(common)->getLoginName();
 
       // ͂ꂽpX[h̎擾
       const char* inputed_password = getPassword();
@@ -888,7 +906,7 @@ struct CreateUser::pImpl {
       if (first_slash != std::string::npos) {
         server = server_address.substr(0, first_slash);
         address = server_address.substr(first_slash, std::string::npos)
-          + "/commitPassword.php?name=" + std::string(&user_name[0])
+          + "commitPassword.php?name=" + std::string(&user_name[0])
           + "&password=" + std::string(inputed_password);
       } else {
         server = server_address;
@@ -1004,7 +1022,7 @@ struct CreateUser::pImpl {
 
   pImpl(void)
     : common(CommonResources::getObject()),
-      scheduler(GameSchedulerId, common),
+      scheduler(0, common),
       title_property(common->font, CreateUser_title,
                      MenuSize, Fore, Back, true),
       title_surface(new TextSurface(title_property)),
