@@ -14,6 +14,9 @@
 #include <memory>
 
 
+/*!
+  \brief ^CsOт̃Ot`
+*/
 class GraphDrawer {
   GraphDrawer(void);
   GraphDrawer(const GraphDrawer& rhs);
@@ -23,12 +26,35 @@ class GraphDrawer {
   const std::auto_ptr<pImpl> pimpl;
 
 public:
+  /*!
+    \brief RXgN^
+
+    \param mode [i] `惂[h
+  */
   explicit GraphDrawer(TypingMode mode);
   ~GraphDrawer(void);
 
-  void drawGraph(void);
+  /*!
+    \brief Ot`
+  */
+  bool drawGraph(void);
+
+  /*!
+    \brief R|[lg̔zu
+  */
   void placeComponents(void);
+
+  /*!
+    \brief R|[lg̏
+  */
   void removeComponents(void);
+
+  /*!
+    \brief sꂽԂ
+
+    \retval true ꂽ
+    \retval false ĂȂ
+  */
   bool keyPressed(void);
 };
 
