@@ -44,9 +44,8 @@ ImageSurface::~ImageSurface(void) {
 
 
 void ImageSurface::draw(std::vector<SDL_Rect>& update_rects,
-                        const SDL_Rect* pos, const SDL_Rect* area,
-                        size_t ticks) {
-  pimpl->surface.draw(update_rects, pos, area, ticks);
+                        const SDL_Rect* pos, const SDL_Rect* area) {
+  pimpl->surface.draw(update_rects, pos, area);
 }
 
 
@@ -65,8 +64,8 @@ void ImageSurface::forceSetChanged(void) {
 }
 
 
-bool ImageSurface::isChanged(void) {
-  return pimpl->surface.isChanged();
+bool ImageSurface::isChanged(size_t ticks) {
+  return pimpl->surface.isChanged(ticks);
 }
 
 
