@@ -110,7 +110,7 @@ struct KimarijiPractice::pImpl {
       // !!!
       // wakaShuffle.shuffle();
 
-      common->recorder->recordGame(rand_seed, TypingRecorder::KimarijiTyping);
+      common->recorder->recordGame(rand_seed, KimarijiTyping);
     }
   };
 
@@ -353,7 +353,7 @@ struct KimarijiPractice::pImpl {
     GraphDrawer graph_drawer;
 
     GraphState(CommonResources* common_obj)
-      : common(common_obj), graph_drawer(ShimonokuTyping) {
+      : common(common_obj), graph_drawer(KimarijiTyping) {
 
       // Otp̏擾Agraph_drawer ɓn
       // !!!
@@ -371,7 +371,12 @@ struct KimarijiPractice::pImpl {
       ResultState::getObject(common)->removeComponents();
 
       // Ot̕`
-      graph_drawer.drawGraph();
+      if (graph_drawer.drawGraph() == false) {
+        // !!! ̏Ԃɕ򂷂ׂ
+        // !!! t@Cp[~bV܂ƂH
+        return;
+      }
+      graph_drawer.placeComponents();
     }
 
     void execute(Schedule* type) {
@@ -432,7 +437,7 @@ struct KimarijiPractice::pImpl {
 
   pImpl(void)
     : common(CommonResources::getObject()),
-      scheduler(GameSchedulerId, common) {
+      scheduler(0, common) {
     TypingState::getObject(common)->setPracticeNum(common->practice_num);
   }
 
