@@ -64,8 +64,8 @@ struct MusicManager::pImpl : private MixerInit {
   ThreadCreator thread;
 
   pImpl(void) : initialized(false), fade_in_msec(0), fade_out_msec(0),
-		current_music_id(0), mutex(SDL_CreateMutex()),
-		thread_args(this), thread(change_thread, &thread_args) {
+                current_music_id(0), mutex(SDL_CreateMutex()),
+                thread_args(this), thread(change_thread, &thread_args) {
 
     if (! isInitialized()) {
       return;
@@ -81,9 +81,9 @@ struct MusicManager::pImpl : private MixerInit {
     // ỷ
     // !!! freeMusResource() g悤ɕύXׂ
     for (MusicMap::iterator it = music_map.begin();
-	 it != music_map.end(); ++it) {
+         it != music_map.end(); ++it) {
       if (it->second.music) {
-	Mix_FreeMusic(it->second.music);
+        Mix_FreeMusic(it->second.music);
       }
     }
 
@@ -111,8 +111,8 @@ struct MusicManager::pImpl : private MixerInit {
     while (true) {
       LockMutex(mutex);
       if (change_order.empty()) {
-	UnlockMutex(mutex);
-	return 0;
+        UnlockMutex(mutex);
+        return 0;
       }
 
       // w߂̎󂯎BŌ̎w߂݈̂
@@ -123,13 +123,13 @@ struct MusicManager::pImpl : private MixerInit {
 
       pImpl::MusicMap::iterator p;
       if (play_times != 0) {
-	p = music_map.find(next_music_id);
-	if (p == music_map.end()) {
-	  // ȂȂ
-	  // !!! G[o
-	  UnlockMutex(mutex);
-	  return -1;
-	}
+        p = music_map.find(next_music_id);
+        if (p == music_map.end()) {
+          // ȂȂ
+          // !!! G[o
+          UnlockMutex(mutex);
+          return -1;
+        }
       }
 
       // tF[hĈ҂
@@ -138,7 +138,7 @@ struct MusicManager::pImpl : private MixerInit {
       UnlockMutex(mutex);
 
       while (Mix_FadingMusic() != MIX_NO_FADING) {
-	delay(10);
+        delay(10);
       }
       LockMutex(mutex);
       Mix_FadeOutMusic(fade_out_msec);
@@ -146,34 +146,34 @@ struct MusicManager::pImpl : private MixerInit {
 
       // tF[hAEg̊҂āÃtF[hn߂
       while (Mix_PlayingMusic()) {
-	delay(10);
+        delay(10);
       }
 
       LockMutex(mutex);
       if (current_music_id != next_music_id) {
-	pImpl::freeMusResource(music_map, current_music_id);
+        pImpl::freeMusResource(music_map, current_music_id);
       }
       if (play_times == 0) {
-	// Ȃ̒~sA߂
-	now_playing = false;
-	UnlockMutex(mutex);
-	continue;
+        // Ȃ̒~sA߂
+        now_playing = false;
+        UnlockMutex(mutex);
+        continue;
       }
 
       // yt@C̓ǂݏo
       p = music_map.find(next_music_id);
       if (p == music_map.end()) {
-	// !!! tF[hɋȂꂽꍇH
-	continue;
+        // !!! tF[hɋȂꂽꍇH
+        continue;
       }
       pImpl::MusicInfo& music_info = p->second;
       if (music_info.music == NULL) {
-	music_info.music = Mix_LoadMUS(music_info.file_path.c_str());
-	if (music_info.music == NULL) {
-	  // !!! G[o
-	  UnlockMutex(mutex);
-	  continue;
-	}
+        music_info.music = Mix_LoadMUS(music_info.file_path.c_str());
+        if (music_info.music == NULL) {
+          // !!! G[o
+          UnlockMutex(mutex);
+          continue;
+        }
       }
 
       // ̋ȂĐ
@@ -190,15 +190,15 @@ struct MusicManager::pImpl : private MixerInit {
   }
 
   static void freeMusResource(MusicMap& music_maps, int music_id,
-			      bool erase = false) {
+                              bool erase = false) {
     MusicMap::iterator p = music_maps.find(music_id);
     if (p != music_maps.end()) {
       if (p->second.music) {
-	Mix_FreeMusic(p->second.music);
-	p->second.music = NULL;
+        Mix_FreeMusic(p->second.music);
+        p->second.music = NULL;
       }
       if (erase) {
-	music_maps.erase(p);
+        music_maps.erase(p);
       }
     }
   }
@@ -292,6 +292,17 @@ void MusicManager::stop(size_t fade_out_msec) {
 }
 
 
+void MusicManager::halt(void) {
+  if (! isInitialized()) {
+    return;
+  }
+
+  Mix_HaltMusic();
+  LockGuard guard(pimpl->mutex);
+  pImpl::now_playing = false;
+}
+
+
 void MusicManager::setFadeInEffect(size_t effect_msec) {
   if (! isInitialized()) {
     return;
