@@ -5,8 +5,6 @@
   \author Satofumi KAMIMURA
 
   $Id$
-
-  \todo uΐf[^̉{vǉ
 */
 
 #include "NetworkMenu.h"
@@ -53,7 +51,8 @@ struct NetworkMenu::pImpl {
     // j[̐Aʒuݒ
     // j[̍ڂ쐬
     const Uint16 *titles[] = {
-      NetworkMenu_player, NetworkMenu_data, NetworkMenu_back,
+      NetworkMenu_player, NetworkMenu_data,
+      NetworkMenu_replay, NetworkMenu_back,
     };
 
     size_t max_width = 0;
@@ -72,6 +71,7 @@ struct NetworkMenu::pImpl {
     menu->setItemsOffset(0, MenuSize + 16);
     menu->setItemSelectWidth(max_width);
     menu->setSelected(0);
+    menu->setIconComponent(common->menu_icon, IconOffset, 0, Middle | Left);
 
     set_SdlRect(&position, centerPosition(menu, 640/2),        480/4 + MenuOffset);
     menu->setPosition(&position);
@@ -80,11 +80,13 @@ struct NetworkMenu::pImpl {
   void placeComponents(void) {
     common->front_layer->push_front(title_label);
     common->front_layer->push_front(menu);
+    common->front_layer->push_front(common->user_label);
   }
 
   void removeComponents(void) {
     common->front_layer->remove(title_label);
     common->front_layer->remove(menu);
+    common->front_layer->remove(common->user_label);
   }
 };
 
@@ -125,6 +127,10 @@ void NetworkMenu::run(void) {
         // !!!
 
       } else if (selected == 2) {
+        // ΐf[^̉{
+        // !!!
+
+      } else if (selected == 3) {
         // ߂
         quit |= true;
       }
