@@ -5,6 +5,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo â̗KR{{bNXőI\ɂ
 */
 
 #include "PracticeMenu.h"
@@ -74,6 +76,7 @@ struct PracticeMenu::pImpl {
     menu->setItemsOffset(0, MenuSize + 16);
     menu->setItemSelectWidth(max_width);
     menu->setSelected(0);
+    menu->setIconComponent(common->menu_icon, IconOffset, 0, Middle | Left);
 
     set_SdlRect(&position, centerPosition(menu, 640/2), 480/4 + MenuOffset);
     menu->setPosition(&position);
@@ -83,11 +86,13 @@ struct PracticeMenu::pImpl {
   void placeComponents(void) {
     common->front_layer->push_front(title_label);
     common->front_layer->push_front(menu);
+    common->front_layer->push_front(common->user_label);
   }
 
   void removeComponents(void) {
     common->front_layer->remove(title_label);
     common->front_layer->remove(menu);
+    common->front_layer->remove(common->user_label);
   }
 
   // y̒~
