@@ -9,6 +9,7 @@
   \todo ͕@̕ύX̂߂ɁARXgN^č\zdg݂
   \todo J[\\
   \todo BS, s̉摜ׂ́Ah炵Ȃ\
+  \todo ҂̉śA^CsOԂɊ܂߂Ȃ悤ɂ
 */
 
 #include "ShimonokuInput.h"
@@ -45,7 +46,6 @@ struct ShimonokuInput::pImpl {
   std::vector<std::vector<Uint16> > judge_text;
   RomanCreator roman_creator;
   std::string roman_complete_sample[2];
-  bool pre_need_bs;
 
   pImpl(TypingMode mode)
     : typing_mode(mode), common(CommonResources::getObject()),
@@ -55,7 +55,7 @@ struct ShimonokuInput::pImpl {
                                         TextOffset,
                                         (InputSize - WakaDrawSize) / 2)),
       converter(common->convert_type), start_ticks(0),
-      waka_index(0), waka_no(0), pre_need_bs(false) {
+      waka_index(0), waka_no(0) {
 
     // !!! ȑOɁArecorder ̕ϊ[h蒼ĂKv
     // !!! ̂ŁATypingTextConverter ̕ϊ[h蒼AH
@@ -66,7 +66,6 @@ struct ShimonokuInput::pImpl {
     // !!! ܂́A\[gꂽL[z󂯓nɂȂ̂ȁH
     // !!! ܂AƂɍl܂傤
 
-    // !!! C[ɓo^܂ł́AbNȂĂ悢
     SDL_Rect position;
     set_SdlRect(&position, (640 - InputWidth)/2,
                 bottomPosition(text_input, 480) - BottomOffset);
@@ -160,10 +159,14 @@ void ShimonokuInput::setNextWaka(void) {
 }
 
 
-void ShimonokuInput::updateWaka(void) {
-  //fprintf(stderr, "ShimonokuInput::updateWaka()\n");
+size_t ShimonokuInput::getCurrentWakaNo(void) {
+  return pimpl->common->waka_order[pimpl->waka_index];
+}
 
-  pimpl->waka_no = pimpl->common->waka_order[pimpl->waka_index];
+
+void ShimonokuInput::updateWaka(void) {
+
+  pimpl->waka_no = getCurrentWakaNo();
 
   // â̔ԍL^
   pimpl->common->recorder->recordWaka(pimpl->waka_no);
@@ -208,14 +211,20 @@ void ShimonokuInput::drawInput(void) {
   std::string roman_sample;
   bool need_bs = pimpl->createRomanSample(roman_sample);
 
-  // need_bs ̕\̓͂ŁAʉ炷B폜L[͗O
-  if ((! pimpl->text_input->isErased()) && (need_bs == true)) {
+  bool is_erased = pimpl->text_input->isErased();
+  if ((! is_erased) && (need_bs != false)) {
+    // need_bs ̕\̓͂ŁA~X炷B폜L[͗O
     if (pimpl->common->music) {
-      // ʉ̍Đ
+      // ~X̍Đ
       pimpl->common->sound_effect->play(Miss);
     }
+  } else if ((! is_erased) && (! pimpl->text_input->empty())) {
+    // 폜L[ȊȌꍇɁAʉ炷
+    if (pimpl->common->music) {
+      // ^Cv̍Đ
+      pimpl->common->sound_effect->play(Type);
+    }
   }
-  pimpl->pre_need_bs = need_bs;
 
   // ͌̍XV
   pimpl->waka_drawer.updateInputSample(pimpl->judge_text,
