@@ -244,7 +244,9 @@ void ShuffleWaka::shuffle(std::vector<int>& waka) {
     break;
 
   case KimarijiTyping:
-    pimpl->kimarijiTypingSort(waka);
+    // !!! kimarijiTypingSort() ܂ł̎b菈
+    pimpl->shimonokuTypingSort(waka);
+    //pimpl->kimarijiTypingSort(waka);
     break;
   }
 }
