@@ -28,14 +28,15 @@ namespace beego {
     ~SwitchSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
-    bool isChanged(void);
+    bool isChanged(size_t ticks);
     bool isTransparent(void);
 
     void clear(void);
+    bool empty(void);
     size_t size(void);
     void registerSurface(Surface surface,
                          int x_offset, int y_offset, size_t index);
