@@ -19,7 +19,7 @@ class TextConvertInterface;
 
 namespace beego {
   class TtfResource;
-
+  class TextProperty;
 
   class TextInputComponent : public ComponentInterface {
     TextInputComponent(const TextInputComponent& rhs);
@@ -30,20 +30,18 @@ namespace beego {
 
   public:
     TextInputComponent(size_t width, size_t height,
-		       TtfResource* font, size_t size,
-		       Uint32 fore_color = beego::White,
-		       Uint32 back_color = beego::Black,
-		       bool transparent = false,
-		       int x_offset = 0, int y_offset = 0);
+                       const TextProperty& property,
+                       int x_offset = 0, int y_offset = 0);
     ~TextInputComponent(void);
 
     void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
-			size_t ticks);
+                        size_t ticks);
     void setPosition(const SDL_Rect* position);
     void getPosition(SDL_Rect* position);
     size_t getWidth(void);
     size_t getHeight(void);
-    void applyInput(const InputEvent& event);
+    void applyInput(const InputEvent& event,
+                    std::vector<SDL_Rect>& applied_rects);
     void registerLayer(Layer* layer);
 
     // !!! ͂󂯕tA󂯕tȂA̐ݒ
@@ -71,6 +69,8 @@ namespace beego {
 
     bool isChanged(void);
 
+    bool isErased(void);
+
     // !!! J[\T[tFX̓o^
   };
 };
