@@ -10,7 +10,12 @@
 */
 
 #include "TypingRecorder.h"
+#include <boost/lexical_cast.hpp>
 #include <ctype.h>
+#include <time.h>
+
+
+using namespace boost;
 
 
 struct TypingRecorder::pImpl {
@@ -55,7 +60,11 @@ void TypingRecorder::recordWaka(size_t no) {
 }
 
 
-void TypingRecorder::evaluate(void) {
+void TypingRecorder::evaluate(const char* user_name) {
+
+  // L^ԁA[U
+  pimpl->data_.time = time(NULL);
+  pimpl->data_.user_name = user_name;
 
   // â̐
   pimpl->waka_num_ = pimpl->data_.waka.size();
@@ -86,11 +95,14 @@ void TypingRecorder::evaluate(void) {
 
   // ^Cv
   pimpl->miss_types_ = miss;
+  pimpl->data_.score.miss_types = pimpl->miss_types_;
 
   // ͊Jnx
   pimpl->start_delay_ = 1.0 * delay / pimpl->waka_num_ / 1000.0;
+  pimpl->data_.score.delay_msec = static_cast<int>(1000 * pimpl->start_delay_);
 
-  //print();
+  // oߎ
+  pimpl->data_.score.elapse_msec = spent;
 }
 
 
@@ -128,8 +140,39 @@ void TypingRecorder::recordTyping(char ch, size_t ticks) {
 }
 
 
-void TypingRecorder::to_s(void) {
+TypingRecorder::GameSettings& TypingRecorder::getRecordData(void) const {
+  return pimpl->data_;
+}
+
+
+std::string TypingRecorder::encodeGameData(const GameSettings& data) {
+
+  // Q[ݒ̃GR[h
+
+  // time_t
+  std::string output = lexical_cast<std::string>(data.time);
+
+  // TypingMode
+  output += (data.mode == ShimonokuTyping) ? ",s" : ",k";
+
+  // user_name
+  output += "," + data.user_name;
+
+  // rand_seed
+  output += "," + lexical_cast<std::string>(data.rand_seed);
+
+  // ~X^C, ͒x, oߎ
+  output += "," + lexical_cast<std::string>(data.score.miss_types);
+  output += "," + lexical_cast<std::string>(data.score.delay_msec);
+  output += "," + lexical_cast<std::string>(data.score.elapse_msec);
+
+  // waka ̐
+  output += "," + lexical_cast<std::string>(data.waka.size());
+
+  // ã̖^CsOf[^
   // !!!
+
+  return output;
 }
 
 
