@@ -10,16 +10,35 @@
   \todo lbg[NΐA̎
   \todo IvVA̎
   \todo I閈ɁAʉ炷
-  \todo ej[ɁAAj[VACRt
   \todo tXN[̂Ƃ́A}EẌړȂΉB
+  \todo lexical_cast ̗OEׂ
+  \todo H̃j[ڂɁAHACRtƂ
 */
 
+#include "hyakutyping.h"
 #include "CommonResources.h"
+#include "ResourceDefinition.h"
 #include "FirstMenu.h"
 #include "SdlVideo.h"
 
 using namespace beego;
 using namespace SDL;
+//using namespace GL;
+
+
+static std::string getSaveDirectory(void) {
+
+  std::string savedir = SaveDir;
+  if (! savedir.compare(0, 2, "~/")) {
+    // "~/" n܂ꍇAϐ HOME Œu
+    const char* home = getenv("HOME");
+    if (home != NULL) {
+      savedir.replace(0, 1, home);
+    }
+  }
+
+  return savedir;
+}
 
 
 /*!
@@ -45,7 +64,18 @@ int main(int argc, char *argv[]) {
     }
   }
 
+  // ʂ̏
+  SdlVideo video;
+  video.setCaption(PACKAGE_STRING);
+  video.setFullscreenMode(fullscreen);
+  if (! video.show()) {
+    printf("SdlVideo::show(): %s\n", video.what());
+    exit(1);
+  }
+
   // f[^̑݃`FbN
+  std::string savedir = getSaveDirectory();
+  CommonResources* common = CommonResources::getObject(savedir.c_str());
   if (! CommonResources::accessFontData()) {
     // tHgf[^Ȃ΁AI
     // !!! \ȂAtHgf[^soCiɊ܂߂
@@ -55,17 +85,7 @@ int main(int argc, char *argv[]) {
     music_mute = true;
   }
 
-  // ʂ̏
-  SdlVideo video;
-  video.setCaption("hyakutyping");
-  video.setFullscreenMode(fullscreen);
-  if (! video.show()) {
-    printf("SdlVideo::show(): %s\n", video.what());
-    exit(1);
-  }
-
   // GUI ̏
-  CommonResources* common = CommonResources::getObject();
   common->initializeGui();
 
   // y̏
